==> kxicq2-0.0.6.tar.gz: kxicq2-0.0.6/kxicq/widgets/kxreceivedmessageimpl.h <==
#ifndef KXRECEIVEDMESSAGEIMPLIMPL_H
#define KXRECEIVEDMESSAGEIMPLIMPL_H

#include <kxhistorywidget.h>
#include "kxreceivedmessage.h"
#include <qwidget.h>
#include <v2_codes.h>
#include <qmultilineedit.h>
#include <qlabel.h>
#include <qlayout.h>

class kxReceivedMessageImpl : public kxReceivedMessage
{ 
  Q_OBJECT

public:
  kxReceivedMessageImpl(QWidget* parent = 0, const char* name = 0 ); // view all
  kxReceivedMessageImpl(UIN, QWidget* parent = 0, const char* name = 0 ); // view all of 1 UIN
  kxReceivedMessageImpl(bool,int, QWidget* parent = 0, const char* name = 0 ); // view message, bool is NOT used !
  kxReceivedMessageImpl(UIN,int, QString, QString, int, QWidget* parent = 0, const char* name = 0 ); // view file ;-)

  ~kxReceivedMessageImpl();
  
  void init();
  
  QString fileMessage;
  int seq;
  int size;
  int showPos;
  QString fileName;
  UIN uin, ruin; //ruin = reply to uin
  UIN oldUin;
  int type; // 1 = all, 0 == UIN
  int msgType;
  bool needAuth;
  QString nick; 
  
  int prevFrame;
  
  void showEvent();
  void setupMessageFrame(int);
  
  QMultiLineEdit* messageString, *urlString;
  QHBoxLayout *urlLayout;
  QVBoxLayout *boxLayout;  
  QLabel *urlLabel;
  
  kxHistoryWidget *historyView;
  QVBoxLayout* vbox_2;

  
public slots:
  void SlotNextButton();
  void SlotCancelButton();
  void SlotReplyButton();
  void SlotAddButton();
  void SlotForwardButton();
  void SlotRecountMessages(UIN);
  void SlotHistoryButton();
  void SlotInfoButton();
  virtual void hide();

  

};

#endif // KXRECEIVEDMESSAGEIMPLIMPL_H

==> kxicq2-0.7.6.tar.gz: kxicq2-0.7.6/kxicq/widgets/kxreceivedmessageimpl.h <==
#ifndef KXRECEIVEDMESSAGEIMPLIMPL_H
#define KXRECEIVEDMESSAGEIMPLIMPL_H

#include <qpushbutton.h>
#include <kxhistorywidget.h>
#include "kxreceivedmessage.h"
#include <qwidget.h>
#include <v2_codes.h>
#include <qmultilineedit.h>
#include <qlabel.h>
#include <qlayout.h>
#include <kxtextbrowser.h>
#include <klistview.h>

class kxReceivedMessageImpl : public kxReceivedMessage
{ 
  Q_OBJECT

public:
  kxReceivedMessageImpl(QWidget* parent = 0, const char* name = 0 ); // view all
  kxReceivedMessageImpl(UIN, QWidget* parent = 0, const char* name = 0 ); // view all of 1 UIN
  kxReceivedMessageImpl(bool,int, QWidget* parent = 0, const char* name = 0 ); // view message, bool is NOT used !
  kxReceivedMessageImpl(UIN,int, QString, QString, int, QWidget* parent = 0, const char* name = 0 ); // view file ;-)

  ~kxReceivedMessageImpl();
  
  void init();
  
  QString fileMessage;
  int seq;
  int size;
  int showPos;
  QString fileName;
  UIN uin, ruin; //ruin = reply to uin
  UIN oldUin;
  int type; // 1 = all, 0 == UIN
  int msgType;
  bool needAuth;
  QString nick;
  QString messageStr;
  
  int prevFrame;
  
  void showEvent();
  void setupMessageFrame(int);
  
  kxTextBrowser* messageString;
  QMultiLineEdit *urlString;
  QHBoxLayout *urlLayout;
  QVBoxLayout *boxLayout;  
  QLabel *urlLabel;
  QPushButton *urlButton;
  KListView *contactView;
  
  kxHistoryWidget *historyView;
  QVBoxLayout* vbox_2;

  
public slots:
  void SlotNextButton();
  void SlotCancelButton();
  void SlotReplyButton();
  void SlotAddButton();
  void SlotForwardButton();
  void SlotRecountMessages(UIN);
  void SlotHistoryButton();
  void SlotInfoButton();
  void SlotUrlButton();
	void SlotClicked(QListViewItem *i);
  virtual void hide();

  /** There has been clicked on a Email referenct,
lets start eg kmail  */
  void slotEMailClick(const QString &, const QString &);
  /** there is clicked on a URL in the output widget, now we must handle the URL
start Konq. for example */
  void slotURLClick(const QString &);
};

#endif // KXRECEIVEDMESSAGEIMPLIMPL_H
